# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/event_reporting/v3/event_reporting_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>envoy/service/event_reporting/v3/event_reporting_service.proto\x12 envoy.service.event_reporting.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xed\x02\n\x13StreamEventsRequest\x12T\n\nidentifier\x18\x01 \x01(\x0b\x32@.envoy.service.event_reporting.v3.StreamEventsRequest.Identifier\x12.\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x8d\x01\n\nIdentifier\x12\x32\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:K\x9a\xc5\x88\x1e\x46\nDenvoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier:@\x9a\xc5\x88\x1e;\n9envoy.service.event_reporting.v2alpha.StreamEventsRequest\"Y\n\x14StreamEventsResponse:A\x9a\xc5\x88\x1e<\n:envoy.service.event_reporting.v2alpha.StreamEventsResponse2\x9d\x01\n\x15\x45ventReportingService\x12\x83\x01\n\x0cStreamEvents\x12\x35.envoy.service.event_reporting.v3.StreamEventsRequest\x1a\x36.envoy.service.event_reporting.v3.StreamEventsResponse\"\x00(\x01\x30\x01\x42\xb1\x01\n.io.envoyproxy.envoy.service.event_reporting.v3B\x1a\x45ventReportingServiceProtoP\x01ZYgithub.com/envoyproxy/go-control-plane/envoy/service/event_reporting/v3;event_reportingv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.event_reporting.v3.event_reporting_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.io.envoyproxy.envoy.service.event_reporting.v3B\032EventReportingServiceProtoP\001ZYgithub.com/envoyproxy/go-control-plane/envoy/service/event_reporting/v3;event_reportingv3\272\200\310\321\006\002\020\002'
  _STREAMEVENTSREQUEST_IDENTIFIER.fields_by_name['node']._options = None
  _STREAMEVENTSREQUEST_IDENTIFIER.fields_by_name['node']._serialized_options = b'\372B\005\212\001\002\020\001'
  _STREAMEVENTSREQUEST_IDENTIFIER._options = None
  _STREAMEVENTSREQUEST_IDENTIFIER._serialized_options = b'\232\305\210\036F\nDenvoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier'
  _STREAMEVENTSREQUEST.fields_by_name['events']._options = None
  _STREAMEVENTSREQUEST.fields_by_name['events']._serialized_options = b'\372B\005\222\001\002\010\001'
  _STREAMEVENTSREQUEST._options = None
  _STREAMEVENTSREQUEST._serialized_options = b'\232\305\210\036;\n9envoy.service.event_reporting.v2alpha.StreamEventsRequest'
  _STREAMEVENTSRESPONSE._options = None
  _STREAMEVENTSRESPONSE._serialized_options = b'\232\305\210\036<\n:envoy.service.event_reporting.v2alpha.StreamEventsResponse'
  _globals['_STREAMEVENTSREQUEST']._serialized_start=252
  _globals['_STREAMEVENTSREQUEST']._serialized_end=617
  _globals['_STREAMEVENTSREQUEST_IDENTIFIER']._serialized_start=410
  _globals['_STREAMEVENTSREQUEST_IDENTIFIER']._serialized_end=551
  _globals['_STREAMEVENTSRESPONSE']._serialized_start=619
  _globals['_STREAMEVENTSRESPONSE']._serialized_end=708
  _globals['_EVENTREPORTINGSERVICE']._serialized_start=711
  _globals['_EVENTREPORTINGSERVICE']._serialized_end=868
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/v3/filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/config/cluster/v3/filter.proto\x12\x17\x65nvoy.config.cluster.v3\x1a(envoy/config/core/v3/config_source.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb6\x01\n\x06\x46ilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12*\n\x0ctyped_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x45\n\x10\x63onfig_discovery\x18\x03 \x01(\x0b\x32+.envoy.config.core.v3.ExtensionConfigSource:\"\x9a\xc5\x88\x1e\x1d\n\x1b\x65nvoy.api.v2.cluster.FilterB\x88\x01\n%io.envoyproxy.envoy.config.cluster.v3B\x0b\x46ilterProtoP\x01ZHgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/v3;clusterv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.cluster.v3.filter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.envoyproxy.envoy.config.cluster.v3B\013FilterProtoP\001ZHgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/v3;clusterv3\272\200\310\321\006\002\020\002'
  _FILTER.fields_by_name['name']._options = None
  _FILTER.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _FILTER._options = None
  _FILTER._serialized_options = b'\232\305\210\036\035\n\033envoy.api.v2.cluster.Filter'
  _globals['_FILTER']._serialized_start=226
  _globals['_FILTER']._serialized_end=408
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/clusters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.admin.v2alpha import metrics_pb2 as envoy_dot_admin_dot_v2alpha_dot_metrics__pb2
from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"envoy/admin/v2alpha/clusters.proto\x12\x13\x65nvoy.admin.v2alpha\x1a!envoy/admin/v2alpha/metrics.proto\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/health_check.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1dudpa/annotations/status.proto\"H\n\x08\x43lusters\x12<\n\x10\x63luster_statuses\x18\x01 \x03(\x0b\x32\".envoy.admin.v2alpha.ClusterStatus\"\xf5\x01\n\rClusterStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\radded_via_api\x18\x02 \x01(\x08\x12<\n\x1fsuccess_rate_ejection_threshold\x18\x03 \x01(\x0b\x32\x13.envoy.type.Percent\x12\x36\n\rhost_statuses\x18\x04 \x03(\x0b\x32\x1f.envoy.admin.v2alpha.HostStatus\x12I\n,local_origin_success_rate_ejection_threshold\x18\x05 \x01(\x0b\x32\x13.envoy.type.Percent\"\xef\x02\n\nHostStatus\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x30\n\x05stats\x18\x02 \x03(\x0b\x32!.envoy.admin.v2alpha.SimpleMetric\x12<\n\rhealth_status\x18\x03 \x01(\x0b\x32%.envoy.admin.v2alpha.HostHealthStatus\x12)\n\x0csuccess_rate\x18\x04 \x01(\x0b\x32\x13.envoy.type.Percent\x12\x0e\n\x06weight\x18\x05 \x01(\r\x12\x10\n\x08hostname\x18\x06 \x01(\t\x12\x10\n\x08priority\x18\x07 \x01(\r\x12\x36\n\x19local_origin_success_rate\x18\x08 \x01(\x0b\x32\x13.envoy.type.Percent\x12-\n\x08locality\x18\t \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\"\xf2\x01\n\x10HostHealthStatus\x12\"\n\x1a\x66\x61iled_active_health_check\x18\x01 \x01(\x08\x12\x1c\n\x14\x66\x61iled_outlier_check\x18\x02 \x01(\x08\x12$\n\x1c\x66\x61iled_active_degraded_check\x18\x04 \x01(\x08\x12\x1f\n\x17pending_dynamic_removal\x18\x05 \x01(\x08\x12\x19\n\x11pending_active_hc\x18\x06 \x01(\x08\x12:\n\x11\x65\x64s_health_status\x18\x03 \x01(\x0e\x32\x1f.envoy.api.v2.core.HealthStatusBx\n!io.envoyproxy.envoy.admin.v2alphaB\rClustersProtoP\x01Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v2alpha.clusters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.envoyproxy.envoy.admin.v2alphaB\rClustersProtoP\001Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_CLUSTERS']._serialized_start=252
  _globals['_CLUSTERS']._serialized_end=324
  _globals['_CLUSTERSTATUS']._serialized_start=327
  _globals['_CLUSTERSTATUS']._serialized_end=572
  _globals['_HOSTSTATUS']._serialized_start=575
  _globals['_HOSTSTATUS']._serialized_end=942
  _globals['_HOSTHEALTHSTATUS']._serialized_start=945
  _globals['_HOSTHEALTHSTATUS']._serialized_end=1187
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/ext_proc/v3/ext_proc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.common.mutation_rules.v3 import mutation_rules_pb2 as envoy_dot_config_dot_common_dot_mutation__rules_dot_v3_dot_mutation__rules__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from envoy.extensions.filters.http.ext_proc.v3 import processing_mode_pb2 as envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3_dot_processing__mode__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8envoy/extensions/filters/http/ext_proc/v3/ext_proc.proto\x12)envoy.extensions.filters.http.ext_proc.v3\x1a:envoy/config/common/mutation_rules/v3/mutation_rules.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a?envoy/extensions/filters/http/ext_proc/v3/processing_mode.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf5\x05\n\x11\x45xternalProcessor\x12\x41\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x02 \x01(\x08\x12R\n\x0fprocessing_mode\x18\x03 \x01(\x0b\x32\x39.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode\x12\x12\n\nasync_mode\x18\x04 \x01(\x08\x12\x1a\n\x12request_attributes\x18\x05 \x03(\t\x12\x1b\n\x13response_attributes\x18\x06 \x03(\t\x12\x41\n\x0fmessage_timeout\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xfa\x42\n\xaa\x01\x07\"\x03\x08\x90\x1c\x32\x00\x12\x13\n\x0bstat_prefix\x18\x08 \x01(\t\x12R\n\x0emutation_rules\x18\t \x01(\x0b\x32:.envoy.config.common.mutation_rules.v3.HeaderMutationRules\x12\x45\n\x13max_message_timeout\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xfa\x42\n\xaa\x01\x07\"\x03\x08\x90\x1c\x32\x00\x12!\n\x19\x64isable_clear_route_cache\x18\x0b \x01(\x08\x12W\n\rforward_rules\x18\x0c \x01(\x0b\x32@.envoy.extensions.filters.http.ext_proc.v3.HeaderForwardingRules\x12\x30\n\x0f\x66ilter_metadata\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1b\n\x13\x61llow_mode_override\x18\x0e \x01(\x08\x12\"\n\x1a\x64isable_immediate_response\x18\x0f \x01(\x08\"\xa0\x01\n\x15HeaderForwardingRules\x12\x41\n\x0f\x61llowed_headers\x18\x01 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcher\x12\x44\n\x12\x64isallowed_headers\x18\x02 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcher\"\x91\x01\n\x0f\x45xtProcPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12P\n\toverrides\x18\x02 \x01(\x0b\x32;.envoy.extensions.filters.http.ext_proc.v3.ExtProcOverridesH\x00\x42\x0f\n\x08override\x12\x03\xf8\x42\x01\"\xec\x01\n\x10\x45xtProcOverrides\x12R\n\x0fprocessing_mode\x18\x01 \x01(\x0b\x32\x39.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode\x12\x12\n\nasync_mode\x18\x02 \x01(\x08\x12\x1a\n\x12request_attributes\x18\x03 \x03(\t\x12\x1b\n\x13response_attributes\x18\x04 \x03(\t\x12\x37\n\x0cgrpc_service\x18\x05 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\xae\x01\n7io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3B\x0c\x45xtProcProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ext_proc/v3;ext_procv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.ext_proc.v3.ext_proc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3B\014ExtProcProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ext_proc/v3;ext_procv3\272\200\310\321\006\002\020\002'
  _EXTERNALPROCESSOR.fields_by_name['grpc_service']._options = None
  _EXTERNALPROCESSOR.fields_by_name['grpc_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _EXTERNALPROCESSOR.fields_by_name['message_timeout']._options = None
  _EXTERNALPROCESSOR.fields_by_name['message_timeout']._serialized_options = b'\372B\n\252\001\007\"\003\010\220\0342\000'
  _EXTERNALPROCESSOR.fields_by_name['max_message_timeout']._options = None
  _EXTERNALPROCESSOR.fields_by_name['max_message_timeout']._serialized_options = b'\372B\n\252\001\007\"\003\010\220\0342\000'
  _EXTPROCPERROUTE.oneofs_by_name['override']._options = None
  _EXTPROCPERROUTE.oneofs_by_name['override']._serialized_options = b'\370B\001'
  _EXTPROCPERROUTE.fields_by_name['disabled']._options = None
  _EXTPROCPERROUTE.fields_by_name['disabled']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_EXTERNALPROCESSOR']._serialized_start=424
  _globals['_EXTERNALPROCESSOR']._serialized_end=1181
  _globals['_HEADERFORWARDINGRULES']._serialized_start=1184
  _globals['_HEADERFORWARDINGRULES']._serialized_end=1344
  _globals['_EXTPROCPERROUTE']._serialized_start=1347
  _globals['_EXTPROCPERROUTE']._serialized_end=1492
  _globals['_EXTPROCOVERRIDES']._serialized_start=1495
  _globals['_EXTPROCOVERRIDES']._serialized_end=1731
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/config_dump.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.bootstrap.v2 import bootstrap_pb2 as envoy_dot_config_dot_bootstrap_dot_v2_dot_bootstrap__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/admin/v2alpha/config_dump.proto\x12\x13\x65nvoy.admin.v2alpha\x1a)envoy/config/bootstrap/v2/bootstrap.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\"3\n\nConfigDump\x12%\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"\x92\x01\n\x12UpdateFailureState\x12\x32\n\x14\x66\x61iled_configuration\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x37\n\x13last_update_attempt\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x64\x65tails\x18\x03 \x01(\t\"\x80\x01\n\x13\x42ootstrapConfigDump\x12\x37\n\tbootstrap\x18\x01 \x01(\x0b\x32$.envoy.config.bootstrap.v2.Bootstrap\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xaa\x06\n\x13ListenersConfigDump\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12Q\n\x10static_listeners\x18\x02 \x03(\x0b\x32\x37.envoy.admin.v2alpha.ListenersConfigDump.StaticListener\x12S\n\x11\x64ynamic_listeners\x18\x03 \x03(\x0b\x32\x38.envoy.admin.v2alpha.ListenersConfigDump.DynamicListener\x1aj\n\x0eStaticListener\x12&\n\x08listener\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x86\x01\n\x14\x44ynamicListenerState\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12&\n\x08listener\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xdf\x02\n\x0f\x44ynamicListener\x12\x0c\n\x04name\x18\x01 \x01(\t\x12S\n\x0c\x61\x63tive_state\x18\x02 \x01(\x0b\x32=.envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState\x12T\n\rwarming_state\x18\x03 \x01(\x0b\x32=.envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState\x12U\n\x0e\x64raining_state\x18\x04 \x01(\x0b\x32=.envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState\x12<\n\x0b\x65rror_state\x18\x05 \x01(\x0b\x32\'.envoy.admin.v2alpha.UpdateFailureState\"\x98\x04\n\x12\x43lustersConfigDump\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12N\n\x0fstatic_clusters\x18\x02 \x03(\x0b\x32\x35.envoy.admin.v2alpha.ClustersConfigDump.StaticCluster\x12W\n\x17\x64ynamic_active_clusters\x18\x03 \x03(\x0b\x32\x36.envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster\x12X\n\x18\x64ynamic_warming_clusters\x18\x04 \x03(\x0b\x32\x36.envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster\x1ah\n\rStaticCluster\x12%\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x7f\n\x0e\x44ynamicCluster\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12%\n\x07\x63luster\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc0\x03\n\x10RoutesConfigDump\x12U\n\x14static_route_configs\x18\x02 \x03(\x0b\x32\x37.envoy.admin.v2alpha.RoutesConfigDump.StaticRouteConfig\x12W\n\x15\x64ynamic_route_configs\x18\x03 \x03(\x0b\x32\x38.envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig\x1aq\n\x11StaticRouteConfig\x12*\n\x0croute_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x88\x01\n\x12\x44ynamicRouteConfig\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12*\n\x0croute_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa9\x04\n\x16ScopedRoutesConfigDump\x12i\n\x1binline_scoped_route_configs\x18\x01 \x03(\x0b\x32\x44.envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs\x12k\n\x1c\x64ynamic_scoped_route_configs\x18\x02 \x03(\x0b\x32\x45.envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs\x1a\x8e\x01\n\x18InlineScopedRouteConfigs\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\x14scoped_route_configs\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xa5\x01\n\x19\x44ynamicScopedRouteConfigs\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cversion_info\x18\x02 \x01(\t\x12\x32\n\x14scoped_route_configs\x18\x03 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x91\x04\n\x11SecretsConfigDump\x12K\n\x0estatic_secrets\x18\x01 \x03(\x0b\x32\x33.envoy.admin.v2alpha.SecretsConfigDump.StaticSecret\x12T\n\x16\x64ynamic_active_secrets\x18\x02 \x03(\x0b\x32\x34.envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret\x12U\n\x17\x64ynamic_warming_secrets\x18\x03 \x03(\x0b\x32\x34.envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret\x1a\x8b\x01\n\rDynamicSecret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cversion_info\x18\x02 \x01(\t\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x06secret\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x1at\n\x0cStaticSecret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x06secret\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyBz\n!io.envoyproxy.envoy.admin.v2alphaB\x0f\x43onfigDumpProtoP\x01Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v2alpha.config_dump_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.envoyproxy.envoy.admin.v2alphaB\017ConfigDumpProtoP\001Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_CONFIGDUMP']._serialized_start=196
  _globals['_CONFIGDUMP']._serialized_end=247
  _globals['_UPDATEFAILURESTATE']._serialized_start=250
  _globals['_UPDATEFAILURESTATE']._serialized_end=396
  _globals['_BOOTSTRAPCONFIGDUMP']._serialized_start=399
  _globals['_BOOTSTRAPCONFIGDUMP']._serialized_end=527
  _globals['_LISTENERSCONFIGDUMP']._serialized_start=530
  _globals['_LISTENERSCONFIGDUMP']._serialized_end=1340
  _globals['_LISTENERSCONFIGDUMP_STATICLISTENER']._serialized_start=743
  _globals['_LISTENERSCONFIGDUMP_STATICLISTENER']._serialized_end=849
  _globals['_LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE']._serialized_start=852
  _globals['_LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE']._serialized_end=986
  _globals['_LISTENERSCONFIGDUMP_DYNAMICLISTENER']._serialized_start=989
  _globals['_LISTENERSCONFIGDUMP_DYNAMICLISTENER']._serialized_end=1340
  _globals['_CLUSTERSCONFIGDUMP']._serialized_start=1343
  _globals['_CLUSTERSCONFIGDUMP']._serialized_end=1879
  _globals['_CLUSTERSCONFIGDUMP_STATICCLUSTER']._serialized_start=1646
  _globals['_CLUSTERSCONFIGDUMP_STATICCLUSTER']._serialized_end=1750
  _globals['_CLUSTERSCONFIGDUMP_DYNAMICCLUSTER']._serialized_start=1752
  _globals['_CLUSTERSCONFIGDUMP_DYNAMICCLUSTER']._serialized_end=1879
  _globals['_ROUTESCONFIGDUMP']._serialized_start=1882
  _globals['_ROUTESCONFIGDUMP']._serialized_end=2330
  _globals['_ROUTESCONFIGDUMP_STATICROUTECONFIG']._serialized_start=2078
  _globals['_ROUTESCONFIGDUMP_STATICROUTECONFIG']._serialized_end=2191
  _globals['_ROUTESCONFIGDUMP_DYNAMICROUTECONFIG']._serialized_start=2194
  _globals['_ROUTESCONFIGDUMP_DYNAMICROUTECONFIG']._serialized_end=2330
  _globals['_SCOPEDROUTESCONFIGDUMP']._serialized_start=2333
  _globals['_SCOPEDROUTESCONFIGDUMP']._serialized_end=2886
  _globals['_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS']._serialized_start=2576
  _globals['_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS']._serialized_end=2718
  _globals['_SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS']._serialized_start=2721
  _globals['_SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS']._serialized_end=2886
  _globals['_SECRETSCONFIGDUMP']._serialized_start=2889
  _globals['_SECRETSCONFIGDUMP']._serialized_end=3418
  _globals['_SECRETSCONFIGDUMP_DYNAMICSECRET']._serialized_start=3161
  _globals['_SECRETSCONFIGDUMP_DYNAMICSECRET']._serialized_end=3300
  _globals['_SECRETSCONFIGDUMP_STATICSECRET']._serialized_start=3302
  _globals['_SECRETSCONFIGDUMP_STATICSECRET']._serialized_end=3418
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/header_to_metadata/v3/header_to_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import regex_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_regex__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLenvoy/extensions/filters/http/header_to_metadata/v3/header_to_metadata.proto\x12\x33\x65nvoy.extensions.filters.http.header_to_metadata.v3\x1a!envoy/type/matcher/v3/regex.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe7\t\n\x06\x43onfig\x12W\n\rrequest_rules\x18\x01 \x03(\x0b\x32@.envoy.extensions.filters.http.header_to_metadata.v3.Config.Rule\x12X\n\x0eresponse_rules\x18\x02 \x03(\x0b\x32@.envoy.extensions.filters.http.header_to_metadata.v3.Config.Rule\x1a\xc7\x03\n\x0cKeyValuePair\x12\x1a\n\x12metadata_namespace\x18\x01 \x01(\t\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12!\n\x05value\x18\x03 \x01(\tB\x12\xf2\x98\xfe\x8f\x05\x0c\x12\nvalue_type\x12_\n\x13regex_value_rewrite\x18\x06 \x01(\x0b\x32..envoy.type.matcher.v3.RegexMatchAndSubstituteB\x12\xf2\x98\xfe\x8f\x05\x0c\x12\nvalue_type\x12]\n\x04type\x18\x04 \x01(\x0e\x32\x45.envoy.extensions.filters.http.header_to_metadata.v3.Config.ValueTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12W\n\x06\x65ncode\x18\x05 \x01(\x0e\x32G.envoy.extensions.filters.http.header_to_metadata.v3.Config.ValueEncode:I\x9a\xc5\x88\x1e\x44\nBenvoy.config.filter.http.header_to_metadata.v2.Config.KeyValuePair\x1a\xc3\x03\n\x04Rule\x12:\n\x06header\x18\x01 \x01(\tB*\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\xf2\x98\xfe\x8f\x05\x19\x12\x17header_cookie_specifier\x12:\n\x06\x63ookie\x18\x05 \x01(\tB*\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\xf2\x98\xfe\x8f\x05\x19\x12\x17header_cookie_specifier\x12w\n\x11on_header_present\x18\x02 \x01(\x0b\x32H.envoy.extensions.filters.http.header_to_metadata.v3.Config.KeyValuePairB\x12\xf2\x98\xfe\x8f\x05\x0c\n\non_present\x12w\n\x11on_header_missing\x18\x03 \x01(\x0b\x32H.envoy.extensions.filters.http.header_to_metadata.v3.Config.KeyValuePairB\x12\xf2\x98\xfe\x8f\x05\x0c\n\non_missing\x12\x0e\n\x06remove\x18\x04 \x01(\x08:A\x9a\xc5\x88\x1e<\n:envoy.config.filter.http.header_to_metadata.v2.Config.Rule\"7\n\tValueType\x12\n\n\x06STRING\x10\x00\x12\n\n\x06NUMBER\x10\x01\x12\x12\n\x0ePROTOBUF_VALUE\x10\x02\"#\n\x0bValueEncode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x42\x41SE64\x10\x01:<\x9a\xc5\x88\x1e\x37\n5envoy.config.filter.http.header_to_metadata.v2.ConfigB\xd5\x01\nAio.envoyproxy.envoy.extensions.filters.http.header_to_metadata.v3B\x15HeaderToMetadataProtoP\x01Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/header_to_metadata/v3;header_to_metadatav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.header_to_metadata.v3.header_to_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.http.header_to_metadata.v3B\025HeaderToMetadataProtoP\001Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/header_to_metadata/v3;header_to_metadatav3\272\200\310\321\006\002\020\002'
  _CONFIG_KEYVALUEPAIR.fields_by_name['key']._options = None
  _CONFIG_KEYVALUEPAIR.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _CONFIG_KEYVALUEPAIR.fields_by_name['value']._options = None
  _CONFIG_KEYVALUEPAIR.fields_by_name['value']._serialized_options = b'\362\230\376\217\005\014\022\nvalue_type'
  _CONFIG_KEYVALUEPAIR.fields_by_name['regex_value_rewrite']._options = None
  _CONFIG_KEYVALUEPAIR.fields_by_name['regex_value_rewrite']._serialized_options = b'\362\230\376\217\005\014\022\nvalue_type'
  _CONFIG_KEYVALUEPAIR.fields_by_name['type']._options = None
  _CONFIG_KEYVALUEPAIR.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CONFIG_KEYVALUEPAIR._options = None
  _CONFIG_KEYVALUEPAIR._serialized_options = b'\232\305\210\036D\nBenvoy.config.filter.http.header_to_metadata.v2.Config.KeyValuePair'
  _CONFIG_RULE.fields_by_name['header']._options = None
  _CONFIG_RULE.fields_by_name['header']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000\362\230\376\217\005\031\022\027header_cookie_specifier'
  _CONFIG_RULE.fields_by_name['cookie']._options = None
  _CONFIG_RULE.fields_by_name['cookie']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000\362\230\376\217\005\031\022\027header_cookie_specifier'
  _CONFIG_RULE.fields_by_name['on_header_present']._options = None
  _CONFIG_RULE.fields_by_name['on_header_present']._serialized_options = b'\362\230\376\217\005\014\n\non_present'
  _CONFIG_RULE.fields_by_name['on_header_missing']._options = None
  _CONFIG_RULE.fields_by_name['on_header_missing']._serialized_options = b'\362\230\376\217\005\014\n\non_missing'
  _CONFIG_RULE._options = None
  _CONFIG_RULE._serialized_options = b'\232\305\210\036<\n:envoy.config.filter.http.header_to_metadata.v2.Config.Rule'
  _CONFIG._options = None
  _CONFIG._serialized_options = b'\232\305\210\0367\n5envoy.config.filter.http.header_to_metadata.v2.Config'
  _globals['_CONFIG']._serialized_start=292
  _globals['_CONFIG']._serialized_end=1547
  _globals['_CONFIG_KEYVALUEPAIR']._serialized_start=482
  _globals['_CONFIG_KEYVALUEPAIR']._serialized_end=937
  _globals['_CONFIG_RULE']._serialized_start=940
  _globals['_CONFIG_RULE']._serialized_end=1391
  _globals['_CONFIG_VALUETYPE']._serialized_start=1393
  _globals['_CONFIG_VALUETYPE']._serialized_end=1448
  _globals['_CONFIG_VALUEENCODE']._serialized_start=1450
  _globals['_CONFIG_VALUEENCODE']._serialized_end=1485
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/network/socket_interface/v3/default_socket_interface.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKenvoy/extensions/network/socket_interface/v3/default_socket_interface.proto\x12,envoy.extensions.network.socket_interface.v3\x1a\x1dudpa/annotations/status.proto\"\x18\n\x16\x44\x65\x66\x61ultSocketInterfaceB\xcb\x01\n:io.envoyproxy.envoy.extensions.network.socket_interface.v3B\x1b\x44\x65\x66\x61ultSocketInterfaceProtoP\x01Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/network/socket_interface/v3;socket_interfacev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.network.socket_interface.v3.default_socket_interface_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n:io.envoyproxy.envoy.extensions.network.socket_interface.v3B\033DefaultSocketInterfaceProtoP\001Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/network/socket_interface/v3;socket_interfacev3\272\200\310\321\006\002\020\002'
  _globals['_DEFAULTSOCKETINTERFACE']._serialized_start=156
  _globals['_DEFAULTSOCKETINTERFACE']._serialized_end=180
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/timeofday.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgoogle/type/timeofday.proto\x12\x0bgoogle.type\"K\n\tTimeOfDay\x12\r\n\x05hours\x18\x01 \x01(\x05\x12\x0f\n\x07minutes\x18\x02 \x01(\x05\x12\x0f\n\x07seconds\x18\x03 \x01(\x05\x12\r\n\x05nanos\x18\x04 \x01(\x05\x42l\n\x0f\x63om.google.typeB\x0eTimeOfDayProtoP\x01Z>google.golang.org/genproto/googleapis/type/timeofday;timeofday\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.timeofday_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017com.google.typeB\016TimeOfDayProtoP\001Z>google.golang.org/genproto/googleapis/type/timeofday;timeofday\370\001\001\242\002\003GTP'
  _globals['_TIMEOFDAY']._serialized_start=44
  _globals['_TIMEOFDAY']._serialized_end=119
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/tap/v3/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.data.tap.v3 import wrapper_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_wrapper__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/service/tap/v3/tap.proto\x12\x14\x65nvoy.service.tap.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1f\x65nvoy/data/tap/v3/wrapper.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe3\x02\n\x11StreamTapsRequest\x12\x46\n\nidentifier\x18\x01 \x01(\x0b\x32\x32.envoy.service.tap.v3.StreamTapsRequest.Identifier\x12\x10\n\x08trace_id\x18\x02 \x01(\x04\x12.\n\x05trace\x18\x03 \x01(\x0b\x32\x1f.envoy.data.tap.v3.TraceWrapper\x1a\x8f\x01\n\nIdentifier\x12\x32\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0e\n\x06tap_id\x18\x02 \x01(\t:=\x9a\xc5\x88\x1e\x38\n6envoy.service.tap.v2alpha.StreamTapsRequest.Identifier:2\x9a\xc5\x88\x1e-\n+envoy.service.tap.v2alpha.StreamTapsRequest\"I\n\x12StreamTapsResponse:3\x9a\xc5\x88\x1e.\n,envoy.service.tap.v2alpha.StreamTapsResponse2u\n\x0eTapSinkService\x12\x63\n\nStreamTaps\x12\'.envoy.service.tap.v3.StreamTapsRequest\x1a(.envoy.service.tap.v3.StreamTapsResponse\"\x00(\x01\x42{\n\"io.envoyproxy.envoy.service.tap.v3B\x08TapProtoP\x01ZAgithub.com/envoyproxy/go-control-plane/envoy/service/tap/v3;tapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.tap.v3.tap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.service.tap.v3B\010TapProtoP\001ZAgithub.com/envoyproxy/go-control-plane/envoy/service/tap/v3;tapv3\272\200\310\321\006\002\020\002'
  _STREAMTAPSREQUEST_IDENTIFIER.fields_by_name['node']._options = None
  _STREAMTAPSREQUEST_IDENTIFIER.fields_by_name['node']._serialized_options = b'\372B\005\212\001\002\020\001'
  _STREAMTAPSREQUEST_IDENTIFIER._options = None
  _STREAMTAPSREQUEST_IDENTIFIER._serialized_options = b'\232\305\210\0368\n6envoy.service.tap.v2alpha.StreamTapsRequest.Identifier'
  _STREAMTAPSREQUEST._options = None
  _STREAMTAPSREQUEST._serialized_options = b'\232\305\210\036-\n+envoy.service.tap.v2alpha.StreamTapsRequest'
  _STREAMTAPSRESPONSE._options = None
  _STREAMTAPSRESPONSE._serialized_options = b'\232\305\210\036.\n,envoy.service.tap.v2alpha.StreamTapsResponse'
  _globals['_STREAMTAPSREQUEST']._serialized_start=214
  _globals['_STREAMTAPSREQUEST']._serialized_end=569
  _globals['_STREAMTAPSREQUEST_IDENTIFIER']._serialized_start=374
  _globals['_STREAMTAPSREQUEST_IDENTIFIER']._serialized_end=517
  _globals['_STREAMTAPSRESPONSE']._serialized_start=571
  _globals['_STREAMTAPSRESPONSE']._serialized_end=644
  _globals['_TAPSINKSERVICE']._serialized_start=646
  _globals['_TAPSINKSERVICE']._serialized_end=763
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/proxy_protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/config/core/v3/proxy_protocol.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xcc\x01\n\x1cProxyProtocolPassThroughTLVs\x12X\n\nmatch_type\x18\x01 \x01(\x0e\x32\x44.envoy.config.core.v3.ProxyProtocolPassThroughTLVs.PassTLVsMatchType\x12\x1f\n\x08tlv_type\x18\x02 \x03(\rB\r\xfa\x42\n\x92\x01\x07\"\x05*\x03\x10\x80\x02\"1\n\x11PassTLVsMatchType\x12\x0f\n\x0bINCLUDE_ALL\x10\x00\x12\x0b\n\x07INCLUDE\x10\x01\"\xc3\x01\n\x13ProxyProtocolConfig\x12\x42\n\x07version\x18\x01 \x01(\x0e\x32\x31.envoy.config.core.v3.ProxyProtocolConfig.Version\x12M\n\x11pass_through_tlvs\x18\x02 \x01(\x0b\x32\x32.envoy.config.core.v3.ProxyProtocolPassThroughTLVs\"\x19\n\x07Version\x12\x06\n\x02V1\x10\x00\x12\x06\n\x02V2\x10\x01\x42\x86\x01\n\"io.envoyproxy.envoy.config.core.v3B\x12ProxyProtocolProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.proxy_protocol_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\022ProxyProtocolProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _PROXYPROTOCOLPASSTHROUGHTLVS.fields_by_name['tlv_type']._options = None
  _PROXYPROTOCOLPASSTHROUGHTLVS.fields_by_name['tlv_type']._serialized_options = b'\372B\n\222\001\007\"\005*\003\020\200\002'
  _globals['_PROXYPROTOCOLPASSTHROUGHTLVS']._serialized_start=124
  _globals['_PROXYPROTOCOLPASSTHROUGHTLVS']._serialized_end=328
  _globals['_PROXYPROTOCOLPASSTHROUGHTLVS_PASSTLVSMATCHTYPE']._serialized_start=279
  _globals['_PROXYPROTOCOLPASSTHROUGHTLVS_PASSTLVSMATCHTYPE']._serialized_end=328
  _globals['_PROXYPROTOCOLCONFIG']._serialized_start=331
  _globals['_PROXYPROTOCOLCONFIG']._serialized_end=526
  _globals['_PROXYPROTOCOLCONFIG_VERSION']._serialized_start=501
  _globals['_PROXYPROTOCOLCONFIG_VERSION']._serialized_end=526
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/matching/common_inputs/network/v3/network_inputs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/extensions/matching/common_inputs/network/v3/network_inputs.proto\x12\x32\x65nvoy.extensions.matching.common_inputs.network.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x14\n\x12\x44\x65stinationIPInput\"\x16\n\x14\x44\x65stinationPortInput\"\x0f\n\rSourceIPInput\"\x11\n\x0fSourcePortInput\"\x15\n\x13\x44irectSourceIPInput\"\x11\n\x0fSourceTypeInput\"\x11\n\x0fServerNameInput\"\x18\n\x16TransportProtocolInput\"\x1a\n\x18\x41pplicationProtocolInput\"(\n\x10\x46ilterStateInput\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\xc5\x01\n@io.envoyproxy.envoy.extensions.matching.common_inputs.network.v3B\x12NetworkInputsProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/common_inputs/network/v3;networkv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.matching.common_inputs.network.v3.network_inputs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n@io.envoyproxy.envoy.extensions.matching.common_inputs.network.v3B\022NetworkInputsProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/common_inputs/network/v3;networkv3\272\200\310\321\006\002\020\002'
  _FILTERSTATEINPUT.fields_by_name['key']._options = None
  _FILTERSTATEINPUT.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DESTINATIONIPINPUT']._serialized_start=183
  _globals['_DESTINATIONIPINPUT']._serialized_end=203
  _globals['_DESTINATIONPORTINPUT']._serialized_start=205
  _globals['_DESTINATIONPORTINPUT']._serialized_end=227
  _globals['_SOURCEIPINPUT']._serialized_start=229
  _globals['_SOURCEIPINPUT']._serialized_end=244
  _globals['_SOURCEPORTINPUT']._serialized_start=246
  _globals['_SOURCEPORTINPUT']._serialized_end=263
  _globals['_DIRECTSOURCEIPINPUT']._serialized_start=265
  _globals['_DIRECTSOURCEIPINPUT']._serialized_end=286
  _globals['_SOURCETYPEINPUT']._serialized_start=288
  _globals['_SOURCETYPEINPUT']._serialized_end=305
  _globals['_SERVERNAMEINPUT']._serialized_start=307
  _globals['_SERVERNAMEINPUT']._serialized_end=324
  _globals['_TRANSPORTPROTOCOLINPUT']._serialized_start=326
  _globals['_TRANSPORTPROTOCOLINPUT']._serialized_end=350
  _globals['_APPLICATIONPROTOCOLINPUT']._serialized_start=352
  _globals['_APPLICATIONPROTOCOLINPUT']._serialized_end=378
  _globals['_FILTERSTATEINPUT']._serialized_start=380
  _globals['_FILTERSTATEINPUT']._serialized_end=420
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/health_check/v3/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/filters/http/health_check/v3/health_check.proto\x12-envoy.extensions.filters.http.health_check.v3\x1a,envoy/config/route/v3/route_components.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xdc\x03\n\x0bHealthCheck\x12?\n\x11pass_through_mode\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12-\n\ncache_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x85\x01\n\x1f\x63luster_min_healthy_percentages\x18\x04 \x03(\x0b\x32\\.envoy.extensions.filters.http.health_check.v3.HealthCheck.ClusterMinHealthyPercentagesEntry\x12\x35\n\x07headers\x18\x05 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher\x1a[\n!ClusterMinHealthyPercentagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.envoy.type.v3.Percent:\x02\x38\x01:;\x9a\xc5\x88\x1e\x36\n4envoy.config.filter.http.health_check.v2.HealthCheckJ\x04\x08\x02\x10\x03\x42\xbe\x01\n;io.envoyproxy.envoy.extensions.filters.http.health_check.v3B\x10HealthCheckProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/health_check/v3;health_checkv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.health_check.v3.health_check_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.filters.http.health_check.v3B\020HealthCheckProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/health_check/v3;health_checkv3\272\200\310\321\006\002\020\002'
  _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY._options = None
  _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY._serialized_options = b'8\001'
  _HEALTHCHECK.fields_by_name['pass_through_mode']._options = None
  _HEALTHCHECK.fields_by_name['pass_through_mode']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HEALTHCHECK._options = None
  _HEALTHCHECK._serialized_options = b'\232\305\210\0366\n4envoy.config.filter.http.health_check.v2.HealthCheck'
  _globals['_HEALTHCHECK']._serialized_start=346
  _globals['_HEALTHCHECK']._serialized_end=822
  _globals['_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY']._serialized_start=664
  _globals['_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY']._serialized_end=755
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/collector/logs/v1/logs_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opentelemetry.proto.logs.v1 import logs_pb2 as opentelemetry_dot_proto_dot_logs_dot_v1_dot_logs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8opentelemetry/proto/collector/logs/v1/logs_service.proto\x12%opentelemetry.proto.collector.logs.v1\x1a&opentelemetry/proto/logs/v1/logs.proto\"\\\n\x18\x45xportLogsServiceRequest\x12@\n\rresource_logs\x18\x01 \x03(\x0b\x32).opentelemetry.proto.logs.v1.ResourceLogs\"\x1b\n\x19\x45xportLogsServiceResponse2\x9d\x01\n\x0bLogsService\x12\x8d\x01\n\x06\x45xport\x12?.opentelemetry.proto.collector.logs.v1.ExportLogsServiceRequest\x1a@.opentelemetry.proto.collector.logs.v1.ExportLogsServiceResponse\"\x00\x42\x86\x01\n(io.opentelemetry.proto.collector.logs.v1B\x10LogsServiceProtoP\x01ZFgithub.com/open-telemetry/opentelemetry-proto/gen/go/collector/logs/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opentelemetry.proto.collector.logs.v1.logs_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.opentelemetry.proto.collector.logs.v1B\020LogsServiceProtoP\001ZFgithub.com/open-telemetry/opentelemetry-proto/gen/go/collector/logs/v1'
  _globals['_EXPORTLOGSSERVICEREQUEST']._serialized_start=139
  _globals['_EXPORTLOGSSERVICEREQUEST']._serialized_end=231
  _globals['_EXPORTLOGSSERVICERESPONSE']._serialized_start=233
  _globals['_EXPORTLOGSSERVICERESPONSE']._serialized_end=260
  _globals['_LOGSSERVICE']._serialized_start=263
  _globals['_LOGSSERVICE']._serialized_end=420
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/load_stats/v2/lrs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.endpoint import load_report_pb2 as envoy_dot_api_dot_v2_dot_endpoint_dot_load__report__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/service/load_stats/v2/lrs.proto\x12\x1b\x65nvoy.service.load_stats.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\'envoy/api/v2/endpoint/load_report.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\"u\n\x10LoadStatsRequest\x12%\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12:\n\rcluster_stats\x18\x02 \x03(\x0b\x32#.envoy.api.v2.endpoint.ClusterStats\"\xa1\x01\n\x11LoadStatsResponse\x12\x10\n\x08\x63lusters\x18\x01 \x03(\t\x12\x19\n\x11send_all_clusters\x18\x04 \x01(\x08\x12:\n\x17load_reporting_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12#\n\x1breport_endpoint_granularity\x18\x03 \x01(\x08\x32\x8e\x01\n\x14LoadReportingService\x12v\n\x0fStreamLoadStats\x12-.envoy.service.load_stats.v2.LoadStatsRequest\x1a..envoy.service.load_stats.v2.LoadStatsResponse\"\x00(\x01\x30\x01\x42\x90\x01\n)io.envoyproxy.envoy.service.load_stats.v2B\x08LrsProtoP\x01ZOgithub.com/envoyproxy/go-control-plane/envoy/service/load_stats/v2;load_statsv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.load_stats.v2.lrs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)io.envoyproxy.envoy.service.load_stats.v2B\010LrsProtoP\001ZOgithub.com/envoyproxy/go-control-plane/envoy/service/load_stats/v2;load_statsv2\272\200\310\321\006\002\020\001'
  _globals['_LOADSTATSREQUEST']._serialized_start=204
  _globals['_LOADSTATSREQUEST']._serialized_end=321
  _globals['_LOADSTATSRESPONSE']._serialized_start=324
  _globals['_LOADSTATSRESPONSE']._serialized_end=485
  _globals['_LOADREPORTINGSERVICE']._serialized_start=488
  _globals['_LOADREPORTINGSERVICE']._serialized_end=630
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/gcp_authn/v3/gcp_authn.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import http_uri_pb2 as envoy_dot_config_dot_core_dot_v3_dot_http__uri__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/filters/http/gcp_authn/v3/gcp_authn.proto\x12*envoy.extensions.filters.http.gcp_authn.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a#envoy/config/core/v3/http_uri.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xad\x02\n\x14GcpAuthnFilterConfig\x12\x39\n\x08http_uri\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.HttpUriB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x37\n\x0cretry_policy\x18\x02 \x01(\x0b\x32!.envoy.config.core.v3.RetryPolicy\x12R\n\x0c\x63\x61\x63he_config\x18\x03 \x01(\x0b\x32<.envoy.extensions.filters.http.gcp_authn.v3.TokenCacheConfig\x12M\n\x0ctoken_header\x18\x04 \x01(\x0b\x32\x37.envoy.extensions.filters.http.gcp_authn.v3.TokenHeader\" \n\x08\x41udience\x12\x14\n\x03url\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"U\n\x10TokenCacheConfig\x12\x41\n\ncache_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\x0f\xfa\x42\x0c\x32\n\x18\xff\xff\xff\xff\xff\xff\xff\xff\x7f\"M\n\x0bTokenHeader\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12!\n\x0cvalue_prefix\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x42\xb2\x01\n8io.envoyproxy.envoy.extensions.filters.http.gcp_authn.v3B\rGcpAuthnProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/gcp_authn/v3;gcp_authnv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.gcp_authn.v3.gcp_authn_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.extensions.filters.http.gcp_authn.v3B\rGcpAuthnProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/gcp_authn/v3;gcp_authnv3\272\200\310\321\006\002\020\002'
  _GCPAUTHNFILTERCONFIG.fields_by_name['http_uri']._options = None
  _GCPAUTHNFILTERCONFIG.fields_by_name['http_uri']._serialized_options = b'\372B\005\212\001\002\020\001'
  _AUDIENCE.fields_by_name['url']._options = None
  _AUDIENCE.fields_by_name['url']._serialized_options = b'\372B\004r\002\020\001'
  _TOKENCACHECONFIG.fields_by_name['cache_size']._options = None
  _TOKENCACHECONFIG.fields_by_name['cache_size']._serialized_options = b'\372B\0142\n\030\377\377\377\377\377\377\377\377\177'
  _TOKENHEADER.fields_by_name['name']._options = None
  _TOKENHEADER.fields_by_name['name']._serialized_options = b'\372B\nr\010\020\001\300\001\001\310\001\000'
  _TOKENHEADER.fields_by_name['value_prefix']._options = None
  _TOKENHEADER.fields_by_name['value_prefix']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _globals['_GCPAUTHNFILTERCONFIG']._serialized_start=265
  _globals['_GCPAUTHNFILTERCONFIG']._serialized_end=566
  _globals['_AUDIENCE']._serialized_start=568
  _globals['_AUDIENCE']._serialized_end=600
  _globals['_TOKENCACHECONFIG']._serialized_start=602
  _globals['_TOKENCACHECONFIG']._serialized_end=687
  _globals['_TOKENHEADER']._serialized_start=689
  _globals['_TOKENHEADER']._serialized_end=766
# @@protoc_insertion_point(module_scope)
